pub fn assemble_for_container(crafting: &CraftingContainer) -> Option<ItemStack>Expand description
Finds and interprets the output for the current crafting container.
pub fn assemble_for_container(crafting: &CraftingContainer) -> Option<ItemStack>Finds and interprets the output for the current crafting container.