pub fn assemble_recipe(
recipe: CraftingRecipeRef,
input: &CraftingInput,
) -> ItemStackExpand description
Interprets passive vanilla crafting data for a concrete input snapshot.
pub fn assemble_recipe(
recipe: CraftingRecipeRef,
input: &CraftingInput,
) -> ItemStackInterprets passive vanilla crafting data for a concrete input snapshot.