pub fn get_remaining_items(
crafting: &CraftingContainer,
) -> Option<(Vec<ItemStack>, PositionedCraftingInput)>Expand description
Returns crafting remainders and the positioned input used to map them back to the original grid.
pub fn get_remaining_items(
crafting: &CraftingContainer,
) -> Option<(Vec<ItemStack>, PositionedCraftingInput)>Returns crafting remainders and the positioned input used to map them back to the original grid.