pub fn slot_changed_crafting_grid<R: Container>(
crafting: &CraftingContainer,
result: &mut R,
)Expand description
Updates a result container from the first matching crafting recipe.
pub fn slot_changed_crafting_grid<R: Container>(
crafting: &CraftingContainer,
result: &mut R,
)Updates a result container from the first matching crafting recipe.