get_remaining_items

Function get_remaining_items 

pub fn get_remaining_items(
    crafting: &CraftingContainer,
    is_2x2: bool,
) -> Option<(Vec<ItemStack>, PositionedCraftingInput)>
Gets the remaining items (crafting remainders) for a recipe.

This queries the recipe for its remaining items, which may include items like empty buckets when using milk buckets in a recipe.

Arguments

  • crafting - The crafting container
  • is_2x2 - Whether this is a 2x2 crafting grid

Returns

A vector of remaining items for each slot in the positioned input, along with the positioned input for mapping back to grid slots. Returns None if no recipe matches.