slot_changed_crafting_grid

Function slot_changed_crafting_grid 

pub fn slot_changed_crafting_grid<R: Container>(
    crafting: &CraftingContainer,
    result: &mut R,
    is_2x2: bool,
)
Called when a slot changes in the crafting grid. Updates the result container with the matching recipe result.

Arguments

  • crafting - The crafting container to check
  • result - The result container to update
  • is_2x2 - Whether this is a 2x2 crafting grid (player inventory)