pub fn slot_changed_crafting_grid<R: Container>(
crafting: &CraftingContainer,
result: &mut R,
is_2x2: bool,
)Expand description
Called when a slot changes in the crafting grid. Updates the result container with the matching recipe result.
Arguments
crafting- The crafting container to checkresult- The result container to updateis_2x2- Whether this is a 2x2 crafting grid (player inventory)